import { aws_ec2 as ec2 } from 'aws-cdk-lib';
import * as constructs from 'constructs';
/** Properties to create a set of AWS service Endpoints */
export interface AwsServiceEndPointsProps {
    /**
         * The vpc in which the service is created
         */
    readonly vpc: ec2.Vpc;
    /**
         * Subnet Group in which to create the service. Typically a subnet Dedicated to the task
         */
    readonly subnetGroup: string;
    /**
         * An arry of InterfaceVPCEndpoints
         */
    readonly services: ec2.InterfaceVpcEndpointAwsService[];
    /** indicate true for a S3 Gateway Interface  */
    readonly s3GatewayInterface?: boolean;
    /** indicate true for a Dynamo Gateway Interface */
    readonly dynamoDBGatewayInterface?: boolean;
}
/**
   * Provisions a set of AWS Service Endpoints in a VPC
   */
export declare class AwsServiceEndPoints extends constructs.Construct {
    /**
         * @param scope The scope that this construct is created in
         * @param id Id for the construct
         * @param props AWSServiceEndpoints
         */
    constructor(scope: constructs.Construct, id: string, props: AwsServiceEndPointsProps);
}
